@@ -371,14 +371,14 @@ class SeqLinear(nn.Module):
             dim=-1
         )
                 
-        log_dt_f = torch.cumsum(-F.leaky_relu(dt + self.dt_bias), dim=1)
+        log_dt_f = torch.cumsum(-F.gelu(dt + self.dt_bias), dim=1)
         log_dt_f = log_dt_f - log_dt_f.topk(1, dim=1).values
         dt_f = torch.exp(log_dt_f)
         z_f = rearrange(z_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
         u_f = rearrange(u_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
         v_f = rearrange(v_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
         
-        log_dt_b = torch.cumsum(-F.leaky_relu(dt.flip() + self.dt_bias), dim=1)
+        log_dt_b = torch.cumsum(-F.gelu(dt.flip() + self.dt_bias), dim=1)
         log_dt_b = log_dt_b - log_dt_b.topk(1, dim=1).values
         dt_b = torch.exp(log_dt_b)
         z_b = rearrange(z_b, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
@@ -437,7 +437,7 @@ class SeqLinear(nn.Module):
             dim=-1
         )
         
-        log_dt = torch.cumsum(-F.leaky_relu(dt + self.dt_bias), dim=1)
+        log_dt = torch.cumsum(-F.gelu(dt + self.dt_bias), dim=1)
         log_dt = log_dt - log_dt.topk(1, dim=1).values
         dt = torch.exp(log_dt)
         z = rearrange(z, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
